@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package SVG::Estimate;
-$SVG::Estimate::VERSION = '1.0006';
+$SVG::Estimate::VERSION = '1.0008';
 use XML::Hash::LX;
 use XML::LibXML;
 use File::Slurp;
@@ -14,6 +14,7 @@ use SVG::Estimate::Ellipse;
 use SVG::Estimate::Polyline;
 use SVG::Estimate::Polygon;
 use SVG::Estimate::Path;
+use Data::Dumper;
 
 with 'SVG::Estimate::Role::Round';
 
@@ -23,7 +24,7 @@ SVG::Estimate - Estimates the length of all the vectors in an SVG file.
 
 =head1 VERSION
 
-version 1.0006
+version 1.0008
 
 =head1 SYNOPSIS
 
@@ -256,6 +257,10 @@ sub sum {
     my $travel_length = 0;
     my $shape_count = 0;
     my $has_transform = 0; ##Flag for g/svg element having a transform
+    ##xml2hash rules
+    ## * Just one element, you get a hash
+    ## * Two elements, you get an array of hashes
+    ## * One element, container has properties, you get an array of hashes
     if (ref $elements eq 'ARRAY') {
         foreach my $element (@{$elements}) {
             my @keys = keys %{$element};
@@ -293,10 +298,9 @@ sub sum {
             }
         }
     }
+    ##Resubmit hashes (which should only have one key/value pair) as an array
     elsif (ref $elements eq 'HASH') {
-        foreach my $key (keys %{ $elements }) {
-            $self->sum($elements->{$key});
-        }
+        $self->sum([ $elements ]);
     }
     $self->length($self->length + $length);
     $self->shape_length($self->shape_length + $shape_length);
